@@ -13,33 +13,38 @@
 # limitations under the License.
 # ============================================================================
 
+from .recommender import Recommender
+
 from .baseline_only import BaselineOnly
 from .bpr import BPR
-from .cdl import CDL
 from .c2pf import C2PF
-from .hpf import HPF
-from .pcrl import PCRL
-from .pmf import PMF
-from .nmf import NMF
-from .mcf import MCF
-from .vmf import VMF
-from .ibpr import IBPR
-from .coe import COE
-from .skm import SKMeans
-from .vbpr import VBPR
-from .online_ibpr import OnlineIBPR
-from .mf import MF
-from .svd import SVD
-from .conv_mf import ConvMF
+from .cdl import CDL
 from .cdr import CDR
-from .sbpr import SBPR
-from .sorec import SoRec
-from .cvae import CVAE
-from .wmf import WMF
-from .vaecf import VAECF
+from .coe import COE
+from .conv_mf import ConvMF
 from .ctr import CTR
+from .cvae import CVAE
+from .efm import EFM
+from .global_avg import GlobalAvg
 from .hft import HFT
+from .hpf import HPF
+from .ibpr import IBPR
+from .mcf import MCF
+from .mf import MF
+from .most_pop import MostPop
+from .mter import MTER
 from .ncf import GMF
 from .ncf import MLP
 from .ncf import NeuMF
-from .efm import EFM
+from .nmf import NMF
+from .online_ibpr import OnlineIBPR
+from .pcrl import PCRL
+from .pmf import PMF
+from .sbpr import SBPR
+from .skm import SKMeans
+from .sorec import SoRec
+from .svd import SVD
+from .vaecf import VAECF
+from .vbpr import VBPR
+from .vmf import VMF
+from .wmf import WMF
\ No newline at end of file
